# -*- coding: utf-8 -*-
"""
Created on Wed Oct 10 16:59:58 2018

@author: wubizhi
"""

import numpy as np
band_array = np.loadtxt('band.txt')

def find_best_match_band(band_array,band_index):
    return np.argmin(np.abs(band_array - band_index))

BLUE_INDEX = find_best_match_band(band_array,470)
GREEN_INDEX = find_best_match_band(band_array,550)
RED_INDEX = find_best_match_band(band_array,650)
NIR_INDEX = find_best_match_band(band_array,860)

def compute_vector_ARVI(SPECTRAL_DATA,NIR,Red,Blue,gamma=1.0):
    num1 = SPECTRAL_DATA[NIR]-(SPECTRAL_DATA[NIR]-gamma*(SPECTRAL_DATA[Blue] - SPECTRAL_DATA[Red]))
    num2 = SPECTRAL_DATA[NIR]+(SPECTRAL_DATA[NIR]-gamma*(SPECTRAL_DATA[Blue] - SPECTRAL_DATA[Red]))
    return (num1)/(num2)

def compute_vector_DVI(SPECTRAL_DATA,NIR,Red):
    return SPECTRAL_DATA[NIR] - SPECTRAL_DATA[Red]

def compute_vector_EVI(SPECTRAL_DATA,NIR,Red,Blue):
    num1 = 2.5*(SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red])
    num2 = (SPECTRAL_DATA[NIR]+6*SPECTRAL_DATA[Red]-7.5*SPECTRAL_DATA[Blue]+1)
    return num1/num2

def compute_vector_GEMI(SPECTRAL_DATA,NIR,Red):
    eta_num1 = 2*(SPECTRAL_DATA[NIR]*SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red]*SPECTRAL_DATA[Red])+1.5*SPECTRAL_DATA[NIR]+0.5*SPECTRAL_DATA[Red]
    eta_num2 = SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]+0.5
    eta = eta_num1/eta_num2
    return eta*(1-0.25*eta)-(SPECTRAL_DATA[Red]-0.125)/(1--SPECTRAL_DATA[Red])

def compute_vector_GARI(SPECTRAL_DATA,NIR,Red,Green,Blue,gamma=1.7):
    num1 = SPECTRAL_DATA[NIR]-(SPECTRAL_DATA[Green]-gamma*(SPECTRAL_DATA[Blue]-SPECTRAL_DATA[Red]))
    num2 = SPECTRAL_DATA[NIR]+(SPECTRAL_DATA[Green]-gamma*(SPECTRAL_DATA[Blue]-SPECTRAL_DATA[Red]))
    return num1/num2

def compute_vector_GDVI(SPECTRAL_DATA,NIR,Green):
    return SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Green]

def compute_vector_GNDVI(SPECTRAL_DATA,NIR,Green):
    num1 = SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Green]
    num2 = SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Green]
    return num1/num2

def compute_vector_GRVI(SPECTRAL_DATA,NIR,Green):
    return SPECTRAL_DATA[NIR]/SPECTRAL_DATA[Green]

def compute_vector_IPVI(SPECTRAL_DATA,NIR,Red):
    return SPECTRAL_DATA[NIR]/(SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red])

def compute_vector_LAI(SPECTRAL_DATA,NIR,Red,Blue):
    EVI = compute_vector_EVI(SPECTRAL_DATA,NIR,Red,Blue)
    return 3.618*EVI-0.118

def compute_vector_MNLI(SPECTRAL_DATA,NIR,Red,L):
    num1 = (1+L)*(SPECTRAL_DATA[NIR]*SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red])
    num2 = SPECTRAL_DATA[NIR]*SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]+L
    return num1/num2

def compute_vector_MSR(SPECTRAL_DATA,NIR,Red):
    num1 = SPECTRAL_DATA[NIR]/SPECTRAL_DATA[Red]-1
    num2 = np.sqrt(SPECTRAL_DATA[NIR]/SPECTRAL_DATA[Red])+1
    return num1/num2

def compute_vector_NLI(SPECTRAL_DATA,NIR,Red):
    num1 = SPECTRAL_DATA[NIR]*SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red]
    num2 = SPECTRAL_DATA[NIR]*SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]
    return num1/num2

def compute_vector_NDVI(SPECTRAL_DATA,NIR,Red):
    num1 = SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red]
    num2 = SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]
    return num1/num2

def compute_vector_OSAVI(SPECTRAL_DATA,NIR,Red):
    num1 = 1.5*(SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red])
    num2 = SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]+0.16
    return num1/num2

def compute_vector_RDVI(SPECTRAL_DATA,NIR,Red):
    num1 = SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red]
    num2 = np.sqrt(SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red])
    return num1/num2    

def compute_vector_SAVI(SPECTRAL_DATA,NIR,Red):
    num1 = 1.5*(SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red])
    num2 = SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]+0.5
    return num1/num2    

def compute_vector_SR(SPECTRAL_DATA,NIR,Red):
    return SPECTRAL_DATA[NIR]/SPECTRAL_DATA[Red]

def compute_vector_SGI(SPECTRAL_DATA,band_array):
    Band_500_index = find_best_match_band(band_array,500)
    Band_600_index = find_best_match_band(band_array,600)
    return np.mean(SPECTRAL_DATA[Band_500_index:Band_600_index+1])

def compute_vector_TDVI(SPECTRAL_DATA,NIR,Red):
    num1 = SPECTRAL_DATA[NIR]-SPECTRAL_DATA[Red]
    num2 = SPECTRAL_DATA[NIR]+SPECTRAL_DATA[Red]
    return np.sqrt(0.5+num1/num2)

def compute_vector_VARI(SPECTRAL_DATA,Red,Green,Blue):
    num1 = SPECTRAL_DATA[Green]-SPECTRAL_DATA[Red]
    num2 = SPECTRAL_DATA[Green]+SPECTRAL_DATA[Red]-SPECTRAL_DATA[Blue]
    return num1/num2

def compute_vector_MCARI(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_670_index = find_best_match_band(band_array,670)
    Band_700_index = find_best_match_band(band_array,700)
    num1 = (SPECTRAL_DATA[Band_700_index]-SPECTRAL_DATA[Band_670_index])-0.2*(SPECTRAL_DATA[Band_700_index]-SPECTRAL_DATA[Band_550_index])
    num2 = (SPECTRAL_DATA[Band_700_index]/SPECTRAL_DATA[Band_670_index])
    return num1*num2

def compute_vector_MCARI2(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_670_index = find_best_match_band(band_array,670)
    Band_800_index = find_best_match_band(band_array,800)
    tmp1 = 2.5*(SPECTRAL_DATA[Band_800_index]-SPECTRAL_DATA[Band_670_index])
    tmp2 = 1.3*(SPECTRAL_DATA[Band_800_index]-SPECTRAL_DATA[Band_550_index])
    num1 = 1.5*(tmp1-tmp2)
    tmp3 = (2*SPECTRAL_DATA[Band_800_index]+1)*(2*SPECTRAL_DATA[Band_800_index]+1)
    tmp4 = 6*SPECTRAL_DATA[Band_800_index]-5*np.sqrt(SPECTRAL_DATA[Band_670_index])
    return num1/np.sqrt(tmp3-tmp4-0.5)

def compute_vector_MRENDVI(SPECTRAL_DATA,band_array):
    Band_445_index = find_best_match_band(band_array,455)
    Band_705_index = find_best_match_band(band_array,705)
    Band_750_index = find_best_match_band(band_array,750)
    num1 =  SPECTRAL_DATA[Band_750_index]-SPECTRAL_DATA[Band_705_index]
    num2 = SPECTRAL_DATA[Band_750_index]+SPECTRAL_DATA[Band_705_index]-2*SPECTRAL_DATA[Band_445_index]
    return num1/num2

def compute_vector_MRESR(SPECTRAL_DATA,band_array):
    Band_445_index = find_best_match_band(band_array,455)
    Band_705_index = find_best_match_band(band_array,705)
    Band_750_index = find_best_match_band(band_array,750)    
    num1 = SPECTRAL_DATA[Band_750_index]-SPECTRAL_DATA[Band_445_index]
    num2 = SPECTRAL_DATA[Band_705_index]-SPECTRAL_DATA[Band_445_index]
    return num1/num2

def compute_vector_MTVI(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_670_index = find_best_match_band(band_array,670)
    Band_800_index = find_best_match_band(band_array,800)
    num1 = 1.2*(SPECTRAL_DATA[Band_800_index]-SPECTRAL_DATA[Band_550_index])
    num2 = 2.5*(SPECTRAL_DATA[Band_670_index]-SPECTRAL_DATA[Band_550_index])
    return 1.2*(num1-num2)

def compute_vector_MTVI2(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_670_index = find_best_match_band(band_array,670)
    Band_800_index = find_best_match_band(band_array,800)
    tmp1 = 1.2*(SPECTRAL_DATA[Band_800_index]-SPECTRAL_DATA[Band_550_index])
    tmp2 = 2.5*(SPECTRAL_DATA[Band_670_index]-SPECTRAL_DATA[Band_550_index])
    tmp3 = (2*SPECTRAL_DATA[Band_800_index]+1)*(2*SPECTRAL_DATA[Band_800_index]+1)
    tmp4 = (6*SPECTRAL_DATA[Band_800_index]-5*np.sqrt(SPECTRAL_DATA[Band_670_index]))
    return 1.5*(tmp1-tmp2)/np.sqrt(tmp3-tmp4-0.5)

def compute_vector_RENDVI(SPECTRAL_DATA,band_array):
    Band_705_index = find_best_match_band(band_array,705)
    Band_750_index = find_best_match_band(band_array,750) 
    num1 = SPECTRAL_DATA[Band_750_index]-SPECTRAL_DATA[Band_705_index]
    num2 = SPECTRAL_DATA[Band_750_index]+SPECTRAL_DATA[Band_705_index]
    return num1/num2

def compute_vector_TCARI(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_670_index = find_best_match_band(band_array,670)
    Band_700_index = find_best_match_band(band_array,700)  
    num1 = SPECTRAL_DATA[Band_700_index]-SPECTRAL_DATA[Band_670_index]
    num2 = 0.2*(SPECTRAL_DATA[Band_700_index]-SPECTRAL_DATA[Band_550_index])*SPECTRAL_DATA[Band_700_index]/SPECTRAL_DATA[Band_670_index]
    return 3*(num1-num2)

def compute_vector_TVI(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_670_index = find_best_match_band(band_array,670)
    Band_750_index = find_best_match_band(band_array,750)
    num1 = 120*(SPECTRAL_DATA[Band_750_index]-SPECTRAL_DATA[Band_550_index])
    num2 = 200*(SPECTRAL_DATA[Band_670_index]-SPECTRAL_DATA[Band_550_index])
    return 0.5*(num1-num2)

def compute_vector_VREI1(SPECTRAL_DATA,band_array):
    Band_740_index = find_best_match_band(band_array,740)
    Band_720_index = find_best_match_band(band_array,720)
    return SPECTRAL_DATA[Band_740_index]/SPECTRAL_DATA[Band_720_index]

def compute_vector_VREI2(SPECTRAL_DATA,band_array):
    Band_734_index = find_best_match_band(band_array,734)
    Band_747_index = find_best_match_band(band_array,747)
    Band_715_index = find_best_match_band(band_array,715)
    Band_726_index = find_best_match_band(band_array,726)
    num1 = SPECTRAL_DATA[Band_734_index]-SPECTRAL_DATA[Band_747_index]
    num2 = SPECTRAL_DATA[Band_715_index]+SPECTRAL_DATA[Band_726_index]
    return num1/num2

def compute_vector_WBI(SPECTRAL_DATA,band_array):
    Band_970_index = find_best_match_band(band_array,970)
    Band_900_index = find_best_match_band(band_array,900)
    return SPECTRAL_DATA[Band_970_index]/SPECTRAL_DATA[Band_900_index]

def compute_vector_PSRI(SPECTRAL_DATA,band_array):
    Band_680_index = find_best_match_band(band_array,680)
    Band_500_index = find_best_match_band(band_array,500)
    Band_750_index = find_best_match_band(band_array,750)    
    return (SPECTRAL_DATA[Band_680_index]-SPECTRAL_DATA[Band_500_index])/SPECTRAL_DATA[Band_750_index]

def compute_vector_ARI1(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_700_index = find_best_match_band(band_array,700)
    return 1.0/SPECTRAL_DATA[Band_550_index]-1.0/SPECTRAL_DATA[Band_700_index]

def compute_vector_ARI2(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_700_index = find_best_match_band(band_array,700)
    Band_800_index = find_best_match_band(band_array,800)
    return SPECTRAL_DATA[Band_800_index]*(1.0/SPECTRAL_DATA[Band_550_index]-1.0/SPECTRAL_DATA[Band_700_index])

def compute_vector_CRI1(SPECTRAL_DATA,band_array):
    Band_550_index = find_best_match_band(band_array,550)
    Band_510_index = find_best_match_band(band_array,510)
    return 1.0/SPECTRAL_DATA[Band_510_index]-1.0/SPECTRAL_DATA[Band_550_index]

def compute_vector_CRI2(SPECTRAL_DATA,band_array):
    Band_700_index = find_best_match_band(band_array,700)
    Band_510_index = find_best_match_band(band_array,510)
    return 1.0/SPECTRAL_DATA[Band_510_index]-1.0/SPECTRAL_DATA[Band_700_index]

def compute_vector_PRI(SPECTRAL_DATA,band_array):
    Band_570_index = find_best_match_band(band_array,570)
    Band_531_index = find_best_match_band(band_array,531)   
    num1 = SPECTRAL_DATA[Band_570_index]-SPECTRAL_DATA[Band_531_index]
    num2 = SPECTRAL_DATA[Band_570_index]+SPECTRAL_DATA[Band_531_index]
    return num1/num2

def compute_vector_SIPI(SPECTRAL_DATA,band_array):
    Band_445_index = find_best_match_band(band_array,455)
    Band_680_index = find_best_match_band(band_array,680)
    Band_800_index = find_best_match_band(band_array,800)
    num1 = 1.2*(SPECTRAL_DATA[Band_800_index]-SPECTRAL_DATA[Band_445_index])
    num2 = 2.5*(SPECTRAL_DATA[Band_800_index]-SPECTRAL_DATA[Band_680_index]) 
    return num1/num2

def compute_vector_RGRI(SPECTRAL_DATA,band_array):
    Band_500_index = find_best_match_band(band_array,500)
    Band_599_index = find_best_match_band(band_array,599)
    Band_600_index = find_best_match_band(band_array,600)   
    Band_699_index = find_best_match_band(band_array,699) 
    num1 = np.mean(SPECTRAL_DATA[Band_600_index:Band_699_index+1])
    num2 = np.mean(SPECTRAL_DATA[Band_500_index:Band_599_index+1])
    return num1/num2

def compute_vector_VI(SPECTRAL_DATA,band_array):
    VI_List = []
    VI_Name_List = []
    
    ARVI = compute_vector_ARVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX,BLUE_INDEX,gamma=1.0)
    VI_List.append(ARVI)
    VI_Name_List.append('ARVI')
    
    DVI = compute_vector_DVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(DVI)
    VI_Name_List.append('DVI')
    
    EVI = compute_vector_EVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX,BLUE_INDEX)
    VI_List.append(EVI)
    VI_Name_List.append('EVI')
    
    GEMI = compute_vector_GEMI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(GEMI)
    VI_Name_List.append('GEMI')
    
    
    GARI = compute_vector_GARI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX,GREEN_INDEX,BLUE_INDEX,gamma=1.7)
    VI_List.append(GARI)
    VI_Name_List.append('GARI')
    
    
    GDVI = compute_vector_GDVI(SPECTRAL_DATA,NIR_INDEX,GREEN_INDEX)
    VI_List.append(GDVI)
    VI_Name_List.append('GDVI')
    
    
    GNDVI = compute_vector_GNDVI(SPECTRAL_DATA,NIR_INDEX,GREEN_INDEX)
    VI_List.append(GNDVI)
    VI_Name_List.append('GNDVI')
    
    
    GRVI = compute_vector_GRVI(SPECTRAL_DATA,NIR_INDEX,GREEN_INDEX)
    VI_List.append(GRVI)
    VI_Name_List.append('GRVI')
    
    
    IPVI = compute_vector_IPVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(IPVI)
    VI_Name_List.append('IPVI')
    
    LAI = compute_vector_LAI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX,BLUE_INDEX)
    VI_List.append(LAI)
    VI_Name_List.append('LAI')
    
    
    MNLI = compute_vector_MNLI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX,L=0.5)
    VI_List.append(MNLI)
    VI_Name_List.append('MNLI')
    
    
    MSR = compute_vector_MSR(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(MSR)
    VI_Name_List.append('MSR')
    
    
    NLI = compute_vector_NLI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(NLI)
    VI_Name_List.append('NLI')
    
    
    NDVI = compute_vector_NDVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(NDVI)
    VI_Name_List.append('NDVI')
    
    OSAVI = compute_vector_OSAVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(OSAVI)
    VI_Name_List.append('OSAVI')
    
    
    RDVI = compute_vector_RDVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(RDVI)
    VI_Name_List.append('RDVI')
    
    
    SAVI = compute_vector_SAVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(SAVI)
    VI_Name_List.append('SAVI')
    
      
    SR = compute_vector_SR(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(SR)
    VI_Name_List.append('SR')
    
    
    SGI = compute_vector_SGI(SPECTRAL_DATA,band_array)
    VI_List.append(SGI)
    VI_Name_List.append('SGI')
    
    
    TDVI = compute_vector_TDVI(SPECTRAL_DATA,NIR_INDEX,RED_INDEX)
    VI_List.append(TDVI)
    VI_Name_List.append('TDVI')
    
    
    VARI = compute_vector_VARI(SPECTRAL_DATA,RED_INDEX,GREEN_INDEX,BLUE_INDEX)
    VI_List.append(VARI)
    VI_Name_List.append('VARI')
    
    
    MACARI = compute_vector_MCARI(SPECTRAL_DATA,band_array)
    VI_List.append(MACARI)
    VI_Name_List.append('MACARI')
    
    
    MCARI2 = compute_vector_MCARI2(SPECTRAL_DATA,band_array)
    VI_List.append(MCARI2)
    VI_Name_List.append('MCARI2')
    
    
    MRENDVI = compute_vector_MRENDVI(SPECTRAL_DATA,band_array)
    VI_List.append(MRENDVI)
    VI_Name_List.append('MRENDVI')
    
    
    MRESR = compute_vector_MRESR(SPECTRAL_DATA,band_array)
    VI_List.append(MRESR)
    VI_Name_List.append('MRESR')
    
    
    MTVI = compute_vector_MTVI(SPECTRAL_DATA,band_array)
    VI_List.append(MTVI)
    VI_Name_List.append('MTVI')
    
    
    MTVI2 = compute_vector_MTVI2(SPECTRAL_DATA,band_array)
    VI_List.append(MTVI2)
    VI_Name_List.append('MTVI2')
    
    
    RENDVI = compute_vector_RENDVI(SPECTRAL_DATA,band_array)
    VI_List.append(RENDVI)
    VI_Name_List.append('RENDVI')
    
    
    TCARI = compute_vector_TCARI(SPECTRAL_DATA,band_array)
    VI_List.append(TCARI)
    VI_Name_List.append('TCARI')
    
    
    TVI = compute_vector_TVI(SPECTRAL_DATA,band_array)
    VI_List.append(TVI)
    VI_Name_List.append('TVI')
    
    
    VREI1 = compute_vector_VREI1(SPECTRAL_DATA,band_array)
    VI_List.append(VREI1)
    VI_Name_List.append('VREI1')
    
    
    VREI2 = compute_vector_VREI2(SPECTRAL_DATA,band_array)
    VI_List.append(VREI2)
    VI_Name_List.append('VREI2')
    
    
    WBI = compute_vector_WBI(SPECTRAL_DATA,band_array)
    VI_List.append(WBI)
    VI_Name_List.append('WBI')
    
    
    PSRI = compute_vector_PSRI(SPECTRAL_DATA,band_array)
    VI_List.append(PSRI)
    VI_Name_List.append('PSRI')
    
    ARI1 = compute_vector_ARI1(SPECTRAL_DATA,band_array)
    VI_List.append(ARI1)
    VI_Name_List.append('ARI1')
    
    ARI2 = compute_vector_ARI2(SPECTRAL_DATA,band_array)
    VI_List.append(ARI2)
    VI_Name_List.append('ARI2')
    
    CRI1 = compute_vector_CRI1(SPECTRAL_DATA,band_array)
    VI_List.append(CRI1)
    VI_Name_List.append('CRI1')
    
    CRI2 = compute_vector_CRI2(SPECTRAL_DATA,band_array)
    VI_List.append(CRI2)
    VI_Name_List.append('CRI2')
    
    PRI = compute_vector_PRI(SPECTRAL_DATA,band_array)
    VI_List.append(PRI)
    VI_Name_List.append('PRI')
    
    SIPI = compute_vector_SIPI(SPECTRAL_DATA,band_array)
    VI_List.append(SIPI)
    VI_Name_List.append('SIPI')
    
    RGRI = compute_vector_RGRI(SPECTRAL_DATA,band_array)
    VI_List.append(RGRI)
    VI_Name_List.append('RGRI')
    return VI_List,VI_Name_List