# -*- coding: utf-8 -*-
"""
Created on Wed Mar 13 13:39:58 2019

@author: wubizhi

程序的作用
    --1.对第六块地，第七块地的数据进行采样
    --2.每块地采集300个点
    --3.每个按照中心点九个点的平均光谱进行存储
    --4.数据最终保存为[3,13,300,176]的npy文件形式
        代表，3个重复，13个品种，每个品种300个平均值抽样点，一共是176个波段
"""

import numpy as np
import spectral.io.envi as envi
import spectral
from scipy.stats import shapiro
import os
import VI_Compute_Matrix 
import pandas as pd
#import VI_Compute_Vecstor

# 波段数目    
spectral_num = 176
# 每个小区采集的样本数目
ROI_sample_num =  500
# 高光谱文件的头文件名
hdr_file_list = ["full"]

# 
delta_x = np.array([-1,-1,-1, 0, 0, 0, 1, 1, 1])
delta_y = np.array([-1, 0, 1, -1,0, 1,-1, 0, 1])


# 对每个高光谱文件进行采样    
for index,hdr_file_name in enumerate(hdr_file_list):
    # 每个ROI的位置信息
    point_file = hdr_file_name + '_point.txt'
    points = np.loadtxt(point_file)
    
    # 高光谱头文件
    hdr_file = hdr_file_name + '.hdr'
    HSI = envi.open(hdr_file)
    Raster_data = HSI[:,:,:]

    
    # 采样数据

    data_sampling = np.zeros([24,ROI_sample_num,spectral_num])
    data_rank_label = np.zeros([24,ROI_sample_num,1]) 

    
    # 开始遍历每个点
    for num,point in enumerate(points):
        print(num)

        left_x,left_y,right_x,right_y = point 
        check_visit_list = []#用来存储是否访问过，以防止重复采样
        it_count = 0 # 计数器，用来计算采样的个数
        while(it_count<ROI_sample_num):

            data_rank_label[num,it_count,:] = (num%8)+1

            #生成采样的点
            # 先生成 x轴的，再生成y轴的
            sub_x = np.random.randint(int(left_x),int(right_x),1)
            sub_y = np.random.randint(int(left_y),int(right_y),1)
            if([sub_x,sub_y] not in check_visit_list):
                check_visit_list.append([sub_x,sub_y])
                sub_hsi_spectral = Raster_data[sub_y,sub_x,:]# 这里要注意是y在前，x在后
                if(not (sub_hsi_spectral==0).all()):
                    data_sampling[num,it_count,:] = sub_hsi_spectral# 这是单个点的采样
                    # 接下来进行以单个点中心，周围8个点均值的采样
                    # 为什么不能直接用mean，因为要避免全零光谱的去除
                    temp_spectral = np.zeros([9,spectral_num])
                    mean_total = 9
                    for it in range(9):
                        temp_spectral[it] = Raster_data[sub_y+delta_y[it],sub_x+delta_x[it],:]
                        if((sub_hsi_spectral==0).all()):
                            mean_total = mean_total - 1
                    mean_sampling_spectral = np.sum(temp_spectral,axis=0)/mean_total
#                    data_mean_sampling[repeat_inx,spec_inx,it_count,:] = mean_sampling_spectral
                    # 计数器加1    
                    it_count = it_count + 1
    data_sampling_file = hdr_file_name +'_sampling.txt'
    data_sampling_with_label = np.concatenate([data_sampling,data_rank_label],axis=2)
    data_sampling_with_label = np.reshape(data_sampling_with_label,[-1,177])
    np.savetxt(data_sampling_file,data_sampling_with_label)

#    np.savetxt('raw_spectral.csv',data_sampling_with_label,delimiter=',',fmt='%.6f')
    
    VI_compute_temp =np.ones([len(data_sampling),176])
    for inx in range(len(data_sampling)):
        data_inx = data_sampling[inx,:,:]
        mean_spectral = np.mean(data_inx,axis=0)
        VI_compute_temp[inx,:] = mean_spectral
#    data_sampling = np.reshape(data_sampling,[-1,176])
    VI_List,VI_Name_List,VI_Array = VI_Compute_Matrix.compute_VI(VI_compute_temp,VI_Compute_Matrix.band_array)
    np.savetxt('mean_spectral.csv',VI_compute_temp,delimiter=',',fmt='%.6f')
#    np.savetxt('data_VI.txt',VI_Array,fmt='%.6f')
    
    VI_List,VI_Name_List,VI_Array = VI_Compute_Matrix.compute_VI(data_sampling_with_label[:,:-1],VI_Compute_Matrix.band_array)
    col = {}
    it = 0
    for i in range(1,4):
        for j in range(1,9):
            rep = 'repeat_'+str(i)+'_'+str(j)
            for _ in range(500):
                col[it] = rep
                it =  it + 1
    tmp = data_sampling_with_label[:,-1]
    tmp = np.reshape(tmp,[-1,1])
    VI = np.concatenate([VI_Array,tmp],axis=1)
    VI_Name_List.append('label')
    df = pd.DataFrame(VI,columns=VI_Name_List)
    df.rename(col,axis='index',inplace=True)
    df.to_csv('raw_spectral.csv')
        
    
#    data_rank_label_file = hdr_file_name +'_rank_label'
#    np.save(data_sampling_file,data_sampling)
#    np.save(data_rank_label_file,data_rank_label)
    
    

 

